@@ -1,5 +1,6 @@
 from __future__ import division
 
+import datetime
 import math
 import multiprocessing
 from multiprocessing import Pool
@@ -67,6 +68,19 @@ def get_video_n_frame(video_path):
     return int(metadata['video']['@nb_frames'])
 
 
+def get_video_creation_time(video_path):
+    metadata = skvideo.io.ffprobe(video_path)
+    tag_dict = {}
+    for tag in metadata['video']['tag']:
+        tag_dict[tag['@key']] = tag['@value']
+    if 'creation_time' not in tag_dict:
+        return None
+    creation_time = tag_dict['creation_time']
+    created_at = datetime.datetime.strptime(
+        creation_time, '%Y-%m-%dT%H:%M:%S.%fZ')
+    return created_at
+
+
 def split_video(video_file_path, output_path=None,
                 start_time=None, end_time=None,
                 hflip=False, vflip=False,
